@@ -86,7 +86,7 @@ Extending JSONEncoder::
 Note that the JSON produced by this module's default settings
 is a subset of YAML, so it may be used as a serializer for that as well.
 """
-__version__ = '1.5'
+__version__ = '1.6'
 __all__ = [
     'dump', 'dumps', 'load', 'loads',
     'JSONDecoder', 'JSONEncoder',
@@ -96,7 +96,7 @@ from decoder import JSONDecoder
 from encoder import JSONEncoder
 
 def dump(obj, fp, skipkeys=False, ensure_ascii=True, check_circular=True,
-        allow_nan=True, cls=None, indent=None, **kw):
+        allow_nan=True, cls=None, indent=None, encoding='utf-8', **kw):
     """
     Serialize ``obj`` as a JSON formatted stream to ``fp`` (a
     ``.write()``-supporting file-like object).
@@ -107,7 +107,7 @@ def dump(obj, fp, skipkeys=False, ensure_ascii=True, check_circular=True,
 
     If ``ensure_ascii`` is ``False``, then the some chunks written to ``fp``
     may be ``unicode`` instances, subject to normal Python ``str`` to
-    ``unicode`` coercion rules.  Unless ``fp.write()`` explicitly
+    ``unicode`` coercion rules. Unless ``fp.write()`` explicitly
     understands ``unicode`` (as in ``codecs.getwriter()``) this is likely
     to cause an error.
 
@@ -121,8 +121,10 @@ def dump(obj, fp, skipkeys=False, ensure_ascii=True, check_circular=True,
     JavaScript equivalents (``NaN``, ``Infinity``, ``-Infinity``).
 
     If ``indent`` is a non-negative integer, then JSON array elements and object
-    members will be pretty-printed with that indent level.  An indent level
-    of 0 will only insert newlines.  ``None`` is the most compact representation.
+    members will be pretty-printed with that indent level. An indent level
+    of 0 will only insert newlines. ``None`` is the most compact representation.
+
+    ``encoding`` is the character encoding for str instances, default is UTF-8.
 
     To use a custom ``JSONEncoder`` subclass (e.g. one that overrides the
     ``.default()`` method to serialize additional types), specify it with
@@ -132,14 +134,15 @@ def dump(obj, fp, skipkeys=False, ensure_ascii=True, check_circular=True,
         cls = JSONEncoder
     iterable = cls(skipkeys=skipkeys, ensure_ascii=ensure_ascii,
         check_circular=check_circular, allow_nan=allow_nan, indent=indent,
-        **kw).iterencode(obj)
+        encoding=encoding, **kw).iterencode(obj)
     # could accelerate with writelines in some versions of Python, at
     # a debuggability cost
     for chunk in iterable:
         fp.write(chunk)
 
 def dumps(obj, skipkeys=False, ensure_ascii=True, check_circular=True,
-        allow_nan=True, cls=None, indent=None, separators=None, **kw):
+        allow_nan=True, cls=None, indent=None, separators=None,
+        encoding='utf-8', **kw):
     """
     Serialize ``obj`` to a JSON formatted ``str``.
 
@@ -161,14 +164,16 @@ def dumps(obj, skipkeys=False, ensure_ascii=True, check_circular=True,
     JavaScript equivalents (``NaN``, ``Infinity``, ``-Infinity``).
 
     If ``indent`` is a non-negative integer, then JSON array elements and
-    object members will be pretty-printed with that indent level.  An indent
-    level of 0 will only insert newlines.  ``None`` is the most compact
+    object members will be pretty-printed with that indent level. An indent
+    level of 0 will only insert newlines. ``None`` is the most compact
     representation.
 
     If ``separators`` is an ``(item_separator, dict_separator)`` tuple
     then it will be used instead of the default ``(', ', ': ')`` separators.
     ``(',', ':')`` is the most compact JSON representation.
 
+    ``encoding`` is the character encoding for str instances, default is UTF-8.
+
     To use a custom ``JSONEncoder`` subclass (e.g. one that overrides the
     ``.default()`` method to serialize additional types), specify it with
     the ``cls`` kwarg.
@@ -178,7 +183,7 @@ def dumps(obj, skipkeys=False, ensure_ascii=True, check_circular=True,
     return cls(
         skipkeys=skipkeys, ensure_ascii=ensure_ascii,
         check_circular=check_circular, allow_nan=allow_nan, indent=indent,
-        separators=separators,
+        separators=separators, encoding=encoding,
         **kw).encode(obj)
 
 def load(fp, encoding=None, cls=None, object_hook=None, **kw):
@@ -188,14 +193,14 @@ def load(fp, encoding=None, cls=None, object_hook=None, **kw):
 
     If the contents of ``fp`` is encoded with an ASCII based encoding other
     than utf-8 (e.g. latin-1), then an appropriate ``encoding`` name must
-    be specified.  Encodings that are not ASCII based (such as UCS-2) are
+    be specified. Encodings that are not ASCII based (such as UCS-2) are
     not allowed, and should be wrapped with
     ``codecs.getreader(fp)(encoding)``, or simply decoded to a ``unicode``
     object and passed to ``loads()``
 
     ``object_hook`` is an optional function that will be called with the
-    result of any object literal decode (a ``dict``).  The return value of
-    ``object_hook`` will be used instead of the ``dict``.  This feature
+    result of any object literal decode (a ``dict``). The return value of
+    ``object_hook`` will be used instead of the ``dict``. This feature
     can be used to implement custom decoders (e.g. JSON-RPC class hinting).
     
     To use a custom ``JSONDecoder`` subclass, specify it with the ``cls``
@@ -214,12 +219,12 @@ def loads(s, encoding=None, cls=None, object_hook=None, **kw):
 
     If ``s`` is a ``str`` instance and is encoded with an ASCII based encoding
     other than utf-8 (e.g. latin-1) then an appropriate ``encoding`` name
-    must be specified.  Encodings that are not ASCII based (such as UCS-2)
+    must be specified. Encodings that are not ASCII based (such as UCS-2)
     are not allowed and should be decoded to ``unicode`` first.
 
     ``object_hook`` is an optional function that will be called with the
-    result of any object literal decode (a ``dict``).  The return value of
-    ``object_hook`` will be used instead of the ``dict``.  This feature
+    result of any object literal decode (a ``dict``). The return value of
+    ``object_hook`` will be used instead of the ``dict``. This feature
     can be used to implement custom decoders (e.g. JSON-RPC class hinting).
 
     To use a custom ``JSONDecoder`` subclass, specify it with the ``cls``
@@ -233,7 +238,7 @@ def loads(s, encoding=None, cls=None, object_hook=None, **kw):
 
 def read(s):
     """
-    json-py API compatibility hook.  Use loads(s) instead.
+    json-py API compatibility hook. Use loads(s) instead.
     """
     import warnings
     warnings.warn("simplejson.loads(s) should be used instead of read(s)",
@@ -242,7 +247,7 @@ def read(s):
 
 def write(obj):
     """
-    json-py API compatibility hook.  Use dumps(s) instead.
+    json-py API compatibility hook. Use dumps(s) instead.
     """
     import warnings
     warnings.warn("simplejson.dumps(s) should be used instead of write(s)",
